==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LegendMouseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseEventArgsDescription } from "./LegendMouseEventArgsDescription";
/**
 * @hidden
 */
export let LegendMouseEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LegendMouseEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LegendMouseEventArgsDescriptionMetadata.a == null) {
                LegendMouseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LegendMouseEventArgsDescriptionMetadata.c(LegendMouseEventArgsDescriptionMetadata.a);
            }
            if (a.k(LegendMouseEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(LegendMouseEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("LegendItemRef", "(w:LegendItem,wf:LegendItem)DataRef");
        }
        static d(a) {
            LegendMouseEventArgsDescriptionMetadata.b(a);
            a.ac("LegendMouseEventArgs", () => new LegendMouseEventArgsDescription());
            a.ab("LegendMouseEventArgs", LegendMouseEventArgsDescriptionMetadata.a);
        }
    }
    LegendMouseEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(LegendMouseEventArgsDescriptionMetadata, 'LegendMouseEventArgsDescriptionMetadata');
    LegendMouseEventArgsDescriptionMetadata.a = null;
    return LegendMouseEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/LegendMouseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseEventArgsDescription } from "./LegendMouseEventArgsDescription";
/**
 * @hidden
 */
export let LegendMouseEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LegendMouseEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LegendMouseEventArgsDescriptionMetadata.a == null) {
                LegendMouseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LegendMouseEventArgsDescriptionMetadata.c(LegendMouseEventArgsDescriptionMetadata.a);
            }
            if (a.k(LegendMouseEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(LegendMouseEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("LegendItemRef", "(w:LegendItem,wf:LegendItem)DataRef");
        }
        static d(a) {
            LegendMouseEventArgsDescriptionMetadata.b(a);
            a.ae("LegendMouseEventArgs", () => new LegendMouseEventArgsDescription());
            a.ad("LegendMouseEventArgs", LegendMouseEventArgsDescriptionMetadata.a);
        }
    }
    LegendMouseEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(LegendMouseEventArgsDescriptionMetadata, 'LegendMouseEventArgsDescriptionMetadata');
    LegendMouseEventArgsDescriptionMetadata.a = null;
    return LegendMouseEventArgsDescriptionMetadata;
})();
